from setuptools import setup

setup(name='timyang_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['timyang_distributions'],
      author='Tim Yang',
      author_email='timonyang@gmail.com',
      zip_safe=False)
